==> pondjs-0.4.0.tgz: package/CONTRIBUTING.md <==
# How to contribute to Pond

In general we follow the "fork & pull" model as outlined in the
[GitHub docs](https://help.github.com/articles/using-pull-requests/).

Here are a few additional thoughts on how to make the contribution process as
painless as possible for yourself and for the developers.

1. *Communicate.* please create an GitHub issue in the appropriate GitHub
project communicating your plans.  This allows coordination -- it's possible
someone else has ideas about this topic and it can save a lot of time if
things are disucssed before you dive in. When you submit your pull request
please include the issue number with the discussion relevant to this pull
request.

2. *Work on a branch.* Work on a branch in a fork of the project code. *DO NOT
WORK ON `master` or `develop`.*

3. *Follow the style of the code.* All code must follow the style of the
project. We generally adhere to the [Google JavaScript style
guide](https://google-styleguide.googlecode.com/svn/trunk/javascriptguide.xml).
Please lint your code with a reasonable linting tool.

4. *Create documentation.* All new features must have appropriate docs in the
docs directory. If you are adding a major feature you may wish to create a
new website docs page.  If you are adding a smaller feature you may just wish to
augment one of the existing docs/website pages.

5. *Tests.* We have mocha tests for this library. Please add tests for any
new functionality and of course make sure all existing tests pass.

The [jQuery guidlines](http://contribute.jquery.org/commits-and-pull-requests/)
have some good suggestions for rectifying common Git mistakes

Once you have you are ready to share your code go ahead and follow the
instructions in the [GitHub
docs](https://help.github.com/articles/using-pull-requests/) to submit your
pull request.

==> pondjs-0.5.2.tgz: package/CONTRIBUTING.md <==
# How to contribute to Pond

In general we follow the "fork & pull" model as outlined in the
[GitHub docs](https://help.github.com/articles/using-pull-requests/).

Here are a few additional thoughts on how to make the contribution process as
painless as possible for yourself and for the developers.

1. *Communicate.* please create an GitHub issue in the appropriate GitHub
project communicating your plans.  This allows coordination -- it's possible
someone else has ideas about this topic and it can save a lot of time if
things are disucssed before you dive in. When you submit your pull request
please include the issue number with the discussion relevant to this pull
request.

2. *Work on a branch.* Work on a branch in a fork of the project code. *DO NOT
WORK ON `master` or `develop`.*

3. *Follow the style of the code.* All code must follow the style of the
project. We generally adhere to the [Google JavaScript style
guide](https://google-styleguide.googlecode.com/svn/trunk/javascriptguide.xml).
Please lint your code with a reasonable linting tool.

4. *Create documentation.* All new features must have appropriate docs in the
docs directory. If you are adding a major feature you may wish to create a
new website docs page.  If you are adding a smaller feature you may just wish to
augment one of the existing docs/website pages.

5. *Tests.* We have mocha tests for this library. Please add tests for any
new functionality and of course make sure all existing tests pass. See the
[Contributing](./README.md#contributing) section in the README for more
details on the tests.

The [jQuery guidlines](http://contribute.jquery.org/commits-and-pull-requests/)
have some good suggestions for rectifying common Git mistakes

Once you have you are ready to share your code go ahead and follow the
instructions in the [GitHub
docs](https://help.github.com/articles/using-pull-requests/) to submit your
pull request.
